@@ -60,16 +60,19 @@
   :prefix "riece-"
   :group 'riece)
 
-(defcustom riece-truncate-partial-width-windows nil
-  "If non-nil, truncate lines in splitting windows such as others buffer."
-  :type 'boolean
-  :group 'riece-looks)
-
 (defcustom riece-use-full-window t
   "If non-nil, whole Emacs window is used to display dialogue."
   :type 'boolean
   :group 'riece-looks)
 
+(defcustom riece-window-center-line -2
+  "Line number of center point in window when scrolling.
+If nil, erases the entire frame and then redraws with point in the
+center of the window.  Negative means relative to bottom of window.
+See the document of the function `recenter'."
+  :type 'integer
+  :group 'riece-looks)
+
 (defcustom riece-directory (expand-file-name "~/.riece")
   "Where to look for data files."
   :type 'directory
@@ -80,7 +83,7 @@
   "Where to look for add-on files."
   :type 'directory
   :group 'riece-options)
-  
+
 (defcustom riece-variables-file
   (expand-file-name "init" riece-directory)
   "Where to look for variables."
@@ -110,7 +113,8 @@ way is to put Riece variables on .emacs or file loaded from there."
 			  riece-url
 			  riece-button
 			  riece-menu
-			  riece-icon)
+			  riece-icon
+			  riece-ignore)
   "Add-ons insinuated into Riece."
   :type '(repeat symbol)
   :group 'riece-options)
@@ -158,7 +162,7 @@ way is to put Riece variables on .emacs or file loaded from there."
 	 (args (list spec)))
     (widget-put widget :args args)
     widget))
-  
+
 (defcustom riece-server-alist nil
   "An alist mapping server names to plist."
   :type 'riece-server-spec
@@ -169,6 +173,21 @@ way is to put Riece variables on .emacs or file loaded from there."
   :type 'string
   :group 'riece-server)
 
+(defcustom riece-protocol 'irc
+  "Protocol support."
+  :type 'symbol
+  :group 'riece-server)
+
+(defcustom riece-max-send-size 512
+  "Maximum size of messages to be sent at a time."
+  :type 'integer
+  :group 'riece-server)
+
+(defcustom riece-send-delay 2
+  "Duration of multiple send."
+  :type 'integer
+  :group 'riece-server)
+  
 (defcustom riece-default-password (getenv "IRCPASSWORD")
   "Your password."
   :type '(radio (string :tag "Password")
@@ -270,6 +289,11 @@ way is to put Riece variables on .emacs or file loaded from there."
   :type 'integer
   :group 'riece-options)
 
+(defcustom riece-shrink-buffer-remove-lines 10
+  "Number of lines removed when shrinking channel buffers."
+  :type 'integer
+  :group 'riece-options)
+
 (defcustom riece-max-buffer-size 65535
   "Maximum size of channel buffers."
   :type '(radio (integer :tag "Number of characters")
